@@ -123,7 +123,21 @@ class Workspace(Datamover):
 
 
 class CacheWorkspace:
-    """Manage a cache workspace on the cluster"""
+    """Manage a cache workspace on the cluster
+
+    Attributes
+    ----------
+    id : str
+        identifier of the cache workspace
+    name : str
+        path to the cache workspace
+    ws : Workspace object
+        wrapper for the workspace manager tools on taurus
+
+    Methods
+    -------
+    cleanup : releases the workspace on taurus - the data can still be recovered within 1 day after cleanup
+    """
 
     def __init__(self, path_to_exe: str = '/usr/bin/',
                  id: str = 'cache', expire_in_days: int = 1) -> None:
@@ -154,9 +168,10 @@ class CacheWorkspace:
         str
             path to allocated workspace
         '''
-        out, err = waitfor(
-            self.ws.ws_allocate(
-                self.id, str(self.expire_in_days), '-c', 'temporary_files'))
+        proc = self.ws.ws_allocate(self.id, str(
+            self.expire_in_days), '-c', 'temporary_files')
+        waitfor(proc, discard_output=False)
+        out, _ = proc.communicate()
         self.name = out.strip()
 
     def cleanup(self) -> None:
@@ -208,7 +223,7 @@ def waitfor(proc, timeout_in_s: float = -1,
     timeout_in_s: float, optional (default: endless)
         Timeout in seconds. This process will be interrupted when the timeout is reached.
     discard_output: bool, optional (default: True)
-        The default behavior is to discard dthe process output (to avoid leaving open file pointers). If you need the output of the command, use discard_output=True.
+        The default behavior is to discard the process output (to avoid leaving open file pointers). If you need the output of the command, use discard_output=False.
     Returns
     -------
     int exit code of the process
